set ::spriteinfo [list \
  card 0 0 50 50 \
  notebook-border 50 0 40 40 \
  switch-dis 50 40 40 20 \
  switch-focus-hover 0 50 40 20 \
  switch-focus 0 70 40 20 \
  switch-hover 40 60 40 20 \
  switch-off-dis 90 0 40 20 \
  switch-off-focus-hover 90 20 40 20 \
  switch-off-focus 90 40 40 20 \
  switch-off-hover 80 60 40 20 \
  switch-off-pressed 0 90 40 20 \
  switch-off-rest 40 80 40 20 \
  switch-pressed 80 80 40 20 \
  switch-rest 0 110 40 20 \
  tab-hover 130 0 32 32 \
  tab-rest 130 32 32 32 \
  tab-selected 120 64 32 32 \
  heading-hover 40 100 22 22 \
  heading-pressed 62 100 22 22 \
  heading-rest 84 100 22 22 \
  slider-thumb-dis 106 100 22 22 \
  slider-thumb-focus-hover 128 96 22 22 \
  slider-thumb-focus 0 130 22 22 \
  slider-thumb-hover 22 130 22 22 \
  slider-thumb-pressed 44 122 22 22 \
  slider-thumb-rest 66 122 22 22 \
  slider-trough-hor 88 122 22 22 \
  slider-trough-vert 110 122 22 22 \
  button-accent-dis 132 118 20 20 \
  button-accent-focus-hover 0 152 20 20 \
  button-accent-focus 20 152 20 20 \
  button-accent-hover 40 152 20 20 \
  button-accent-pressed 60 144 20 20 \
  button-accent-rest 80 144 20 20 \
  button-dis 100 144 20 20 \
  button-focus-hover 120 144 20 20 \
  button-focus 140 138 20 20 \
  button-hover 162 0 20 20 \
  button-pressed 162 20 20 20 \
  button-rest 162 40 20 20 \
  check-dis 162 60 20 20 \
  check-focus-hover 150 96 20 20 \
  check-focus 152 116 20 20 \
  check-hover 160 136 20 20 \
  check-pressed 0 172 20 20 \
  check-rest 20 172 20 20 \
  check-tri-dis 40 172 20 20 \
  check-tri-focus-hover 160 156 20 20 \
  check-tri-focus 140 158 20 20 \
  check-tri-hover 60 164 20 20 \
  check-tri-pressed 80 164 20 20 \
  check-tri-rest 100 164 20 20 \
  check-unsel-dis 120 164 20 20 \
  check-unsel-focus-hover 182 0 20 20 \
  check-unsel-focus 182 20 20 20 \
  check-unsel-hover 182 40 20 20 \
  check-unsel-pressed 182 60 20 20 \
  check-unsel-rest 180 80 20 20 \
  progressbar-bar-hor 180 100 20 5 \
  progressbar-bar-vert 172 80 5 20 \
  progressbar-trough-hor 152 80 20 5 \
  progressbar-trough-vert 172 100 5 20 \
  radio-dis 180 105 20 20 \
  radio-focus-hover 180 125 20 20 \
  radio-focus 180 145 20 20 \
  radio-hover 180 165 20 20 \
  radio-pressed 160 176 20 20 \
  radio-rest 140 178 20 20 \
  radio-unsel-dis 0 192 20 20 \
  radio-unsel-focus-hover 20 192 20 20 \
  radio-unsel-focus 40 192 20 20 \
  radio-unsel-hover 180 185 20 20 \
  radio-unsel-pressed 60 184 20 20 \
  radio-unsel-rest 80 184 20 20 \
  scrollbar-thumb-hor 160 196 20 12 \
  scrollbar-thumb-vert 100 184 12 20 \
  scrollbar-trough-hor 112 198 20 12 \
  scrollbar-trough-vert 202 0 12 20 \
  textbox-dis 0 212 20 20 \
  textbox-error 20 212 20 20 \
  textbox-focus 40 212 20 20 \
  textbox-hover 60 210 20 20 \
  textbox-rest 80 210 20 20 \
  down 40 50 10 5 \
  empty 152 64 10 10 \
  grip 152 85 10 10 \
  right 162 85 5 10 \
  sep 202 20 10 10 \
  up 40 55 10 5 \
  scrollbar-down 132 138 8 6 \
  scrollbar-left 44 144 6 8 \
  scrollbar-right 50 144 6 8 \
  scrollbar-up 172 120 8 6 \
]
